package de.cliffbreak.varo.listeners;

import org.bukkit.GameMode;
import org.bukkit.entity.Player;
import org.bukkit.event.EventHandler;
import org.bukkit.event.Listener;
import org.bukkit.event.entity.EntityDamageEvent;
import org.bukkit.event.entity.PlayerDeathEvent;
import org.bukkit.scheduler.BukkitRunnable;

import de.cliffbreak.varo.Varo;

public class PlayerDeathListener implements Listener {

    private final Varo plugin;

    public PlayerDeathListener(final Varo plugin) {
        this.plugin = plugin;
    }

    @EventHandler
    public void onPlayerDeath(final PlayerDeathEvent e) {
        new BukkitRunnable() {
            @Override
            public void run() {
                e.getEntity().kickPlayer("§4Du bist gestorben.\n \n§cDamit bist du aus §eVaro§c ausgeschieden.");
            }
        }.runTaskLater(this.plugin, 20);
        final EntityDamageEvent damageCause = e.getEntity().getLastDamageCause();
        final Player killer = e.getEntity().getKiller();
        if (killer != null) {
            System.out.println(killer.getName());
            this.plugin.getDatabase().addKill(killer.getUniqueId().toString().replace("-", ""),
                    e.getEntity().getUniqueId().toString().replace("-", ""));
        } else {
            System.out.println("No killer");
        }
        System.out.println(damageCause.getCause());
        switch (damageCause.getCause()) {
        case BLOCK_EXPLOSION:
            // TNT
            if (killer == null) {
                e.setDeathMessage("Hier die Todesnachricht einfügen..");
            } else {
                e.setDeathMessage("Hier die Todesnachricht einfügen.. mit " + killer + ".");
            }
            break;
        case CONTACT:
            // Cactus
            break;
        case DROWNING:
            break;
        case ENTITY_EXPLOSION:
            // Creeper
            break;
        case ENTITY_ATTACK:
        case ENTITY_SWEEP_ATTACK:
            break;
        case FALL:
            break;
        case FALLING_BLOCK:
            break;
        case FIRE:
        case FIRE_TICK:
            break;
        case HOT_FLOOR:
            // Magma Block
            break;
        case LAVA:
            break;
        case LIGHTNING:
            break;
        case MAGIC:
            // Potion (should be impossible)
            break;
        case POISON:
            break;
        case PROJECTILE:
            break;
        case STARVATION:
            break;
        case SUFFOCATION:
            // Border damage or sand/gravel
            break;
        case THORNS:
            break;
        case VOID:
            break;
        case WITHER:
            break;
        case CRAMMING: // Very rare so handle as default death
        case CUSTOM: // No custom damage provider so impossible
        case DRAGON_BREATH: // End is disabled so impossible
        case DRYOUT: // No fish so impossible
        case FLY_INTO_WALL: // No Elytra so impossible
        case MELTING: // No snowman so impossible
        case SUICIDE: // No access to /kill command
        default:
            break;
        }

        // Reset health to prevent death dialog after rejoin (if unbanned)
        e.getEntity().setHealth(20d);
        e.getEntity().setGameMode(GameMode.SPECTATOR);

        this.plugin.getBanUtils().addBan(e.getEntity().getUniqueId());
        this.plugin.getDiscordBot().broadcastMessage("Der Spieler <@!"
                + this.plugin.getTeamManager().getDiscordIdByPlayer(e.getEntity()) + "> ist gestorben.");
    }

}