package de.cliffbreak.varo.managers;

import java.time.Duration;
import java.time.Instant;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.time.ZoneId;
import java.time.temporal.ChronoUnit;

import org.bukkit.Bukkit;
import org.bukkit.entity.Player;
import org.bukkit.scheduler.BukkitRunnable;

import de.cliffbreak.varo.Varo;

public class GameTimeManager {

    private final Varo plugin;
    private static final int firstPlayTimeMinutes = 50;
    private static final int firstPlayTimeLoginMinutes = 10;
    private static final LocalTime firstPlayStart = LocalTime.of(19, 10, 00);
    private static final int playTimeMinutes = 30;
    private static final int playTimeLoginMinutes = 5;
    private static final LocalTime playStart = LocalTime.of(19, 30, 00);

    public GameTimeManager(final Varo plugin) {
        this.plugin = plugin;
        startScheduler();
    }

    public int currentDay() {
        final Instant instant = Instant.ofEpochMilli(this.plugin.getConfig().getLong("Varo.Start"));
        final LocalDateTime start = instant.atZone(ZoneId.systemDefault()).toLocalDateTime();
        final LocalDateTime current = LocalDateTime.now();
        return (int) Duration.between(start, current).toDays() + 1;
    }

    public boolean canLogin() {
        final LocalTime currentTime = LocalTime.now();
        if (this.currentDay() == 1) {
            if (!currentTime.isBefore(firstPlayStart.minusMinutes(firstPlayTimeLoginMinutes))
                    && !currentTime.isAfter(firstPlayStart.plusMinutes(firstPlayTimeMinutes))) {
                return true;
            } else {
                return false;
            }
        } else {
            if (!currentTime.isBefore(playStart.minusMinutes(playTimeLoginMinutes))
                    && !currentTime.isAfter(playStart.plusMinutes(playTimeMinutes))) {
                return true;
            } else {
                return false;
            }
        }
    }

    public boolean isLoginTimeOver() {
        final LocalTime currentTime = LocalTime.now();
        if (this.currentDay() == 1) {
            if (currentTime.isAfter(firstPlayStart)) {
                return true;
            } else {
                return false;
            }
        } else {
            if (currentTime.isAfter(playStart)) {
                return true;
            } else {
                return false;
            }
        }
    }

    public int getLoginTimeLeft() {
        final LocalTime currentTime = LocalTime.now();
        return (int) currentTime.until(playStart, ChronoUnit.SECONDS);
    }

    private boolean isPlayTimeOver() {
        final LocalTime currentTime = LocalTime.now();
        if (this.currentDay() == 1) {
            if (currentTime.isAfter(firstPlayStart.plusMinutes(firstPlayTimeMinutes))) {
                return true;
            } else {
                return false;
            }
        } else {
            if (currentTime.isAfter(playStart.plusMinutes(playTimeMinutes))) {
                return true;
            } else {
                return false;
            }
        }
    }

    private void startScheduler() {
        new BukkitRunnable() {
            boolean playersTeleported = false;

            @Override
            public void run() {
                if (isLoginTimeOver()) {
                    if (!this.playersTeleported) {
                        this.playersTeleported = true;
                        System.out.println("Teleport Players!");
                        // plugin.getTeamManager().
                    }
                }
                if (isPlayTimeOver()) {
                    for (final Player p : Bukkit.getOnlinePlayers()) {
                        p.kickPlayer("Spielzeit abgelaufen");
                    }
                    this.cancel();
                }
            }
        }.runTaskTimer(this.plugin, 20l, 20l);
    }

}